import type { ElementSymbol } from '.';
export type Species = {
    element: ElementSymbol;
    occu: number;
};
export type Site = {
    species: Species[];
    abc: number[];
    xyz: number[];
    label: string;
    properties: Record<string, unknown>;
};
export type Lattice = {
    matrix: number[][];
    pbc: boolean[];
    a: number;
    b: number;
    c: number;
    alpha: number;
    beta: number;
    gamma: number;
    volume: number;
};
export type PymatgenStructure = {
    charge: number;
    lattice: Lattice;
    sites: Site[];
};
export declare function get_elem_amount(structure: PymatgenStructure): Record<"H" | "He" | "Li" | "Be" | "B" | "C" | "N" | "O" | "F" | "Ne" | "Na" | "Mg" | "Al" | "Si" | "P" | "S" | "Cl" | "Ar" | "K" | "Ca" | "Sc" | "Ti" | "V" | "Cr" | "Mn" | "Fe" | "Co" | "Ni" | "Cu" | "Zn" | "Ga" | "Ge" | "As" | "Se" | "Br" | "Kr" | "Rb" | "Sr" | "Y" | "Zr" | "Nb" | "Mo" | "Tc" | "Ru" | "Rh" | "Pd" | "Ag" | "Cd" | "In" | "Sn" | "Sb" | "Te" | "I" | "Xe" | "Cs" | "Ba" | "La" | "Ce" | "Pr" | "Nd" | "Pm" | "Sm" | "Eu" | "Gd" | "Tb" | "Dy" | "Ho" | "Er" | "Tm" | "Yb" | "Lu" | "Hf" | "Ta" | "W" | "Re" | "Os" | "Ir" | "Pt" | "Au" | "Hg" | "Tl" | "Pb" | "Bi" | "Po" | "At" | "Rn" | "Fr" | "Ra" | "Ac" | "Th" | "Pa" | "U" | "Np" | "Pu" | "Am" | "Cm" | "Bk" | "Cf" | "Es" | "Fm" | "Md" | "No" | "Lr" | "Rf" | "Db" | "Sg" | "Bh" | "Hs" | "Mt" | "Ds" | "Rg" | "Cn" | "Nh" | "Fl" | "Mc" | "Lv" | "Ts" | "Og", number>;
export declare function alphabetical_formula(structure: PymatgenStructure): string;
export declare const atomic_radii: Record<ElementSymbol, number>;
export declare const atomic_colors: Record<ElementSymbol, string[]>;
export declare const atomic_weights: {
    [k: string]: number;
};
export declare function get_elements(structure: PymatgenStructure): ElementSymbol[];
export declare function density(structure: PymatgenStructure, prec?: string): any;
